======================================
Invenio Groups
======================================

.. image:: https://img.shields.io/travis/inveniosoftware/invenio-groups.svg
        :target: https://travis-ci.org/inveniosoftware/invenio-groups

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-groups.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-groups

.. image:: https://img.shields.io/github/tag/inveniosoftware/invenio-groups.svg
        :target: https://github.com/inveniosoftware/invenio-groups/releases

.. image:: https://img.shields.io/pypi/dm/invenio-groups.svg
        :target: https://pypi.python.org/pypi/invenio-groups

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-groups.svg
        :target: https://github.com/inveniosoftware/invenio-groups/blob/master/LICENSE


Invenio module that adds support for user groups.

* Free software: GPLv2 license
* Documentation: https://invenio-groups.readthedocs.org.
